@@ -94,7 +94,8 @@ class AnchorImage(Explainer):
             segmentation_kwargs=segmentation_kwargs,
             p_sample=self.p_sample,
             seed=seed,
-            image_shape=image_shape
+            image_shape=self.image_shape,
+            images_background=self.images_background
         )
         if not self.custom_segmentation:
             self.meta['params'].update(segmentation_fn=segmentation_fn)
@@ -210,7 +211,7 @@ class AnchorImage(Explainer):
             covered_false = [self._scale(img) for img in covered_false]
             # coverage set to -1.0 as we can't compute 'true'coverage for this model
 
-            return [covered_true, covered_false, labels.astype(int), data, -1.0, anchor[0]]
+            return [covered_true, covered_false, labels.astype(int), data, -1.0, anchor[0]]  # type: ignore
 
         else:
             data = self._choose_superpixels(num_samples)
